Module builder

Module builder 

Traits

BuilderFlow
A BuilderFlow is generic over M which is the mediator that will be built by BuilderFlow::build().
BuilderInternal
Trait for creating a builder that implements BuilderFlow for a mediator M.
TryBuilderFlow
A TryBuilderFlow is generic over M which is the mediator that will be tried to be built by TryBuilderFlow::build().
TryBuilderInternal
Trait for creating a builder that implements TryBuilderFlow for a mediator M.